;; Generated package description from logos.el  -*- no-byte-compile: t -*-
(define-package "logos" "1.0.1" "Simple focus mode and extras" '((emacs "27.1")) :commit "d8f18f74591ffcac6466409ac7cd29f90838b2fe" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Logos Development" . "~protesilaos/logos@lists.sr.ht") :keywords '("convenience" "focus" "writing" "presentation" "narrowing") :url "https://git.sr.ht/~protesilaos/logos")
